export declare enum TokenProviderPathPolicyVariable {
    REPOSITORY = "REPOSITORY",
    REPOSITORY_OWNER = "REPOSITORY_OWNER"
}
export declare enum TokenProviderPathStrategyType {
    POLICY_VAR = "POLICY_VAR",
    ANY_REPOSITORY = "ANY_REPOSITORY",
    OWNER = "OWNER",
    REPOSITORIES = "REPOSITORIES"
}
export declare class TokenProviderPathStrategy {
    private readonly settings;
    /**
     * Grants permission to `/x/<provider-name>/${aws:PrincipalTag/repository}`
     */
    static policyVarRepository(): TokenProviderPathStrategy;
    /**
     * Grants permission to `/x/<provider-name>/${aws:PrincipalTag/repository_owner}` or `/x/<provider-name>/${aws:PrincipalTag/repository_owner}/<repo>`
     */
    static policyVarRepositoryOwner(...repositories: string[]): TokenProviderPathStrategy;
    /**
     * Grants permission to `/x/<provider-name>/*`
     */
    static anyRepository(): TokenProviderPathStrategy;
    /**
     * Grants permission for each specified repo `/x/<provider-name>/<owner>/<repo>`
     */
    static selectRepositories(owner: string, ...repositories: string[]): TokenProviderPathStrategy;
    /**
     * Grants permission to `/x/<provider-name>/<owner>`
     */
    static selectOwner(owner: string): TokenProviderPathStrategy;
    private constructor();
    get type(): TokenProviderPathStrategyType;
    get owner(): string | undefined;
    get repositories(): string[];
    get policyVar(): TokenProviderPathPolicyVariable | undefined;
    get pathTargetsRepositories(): boolean;
}
